/**
  ******************************************************************************
  * @file    Project/STM32F10x_StdPeriph_Template/main.c 
  * @author  MCD Application Team
  * @version V3.5.0
  * @date    08-April-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */  

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include <stdio.h>

// LEDs
#define LED_1_AUS      GPIO_ResetBits(GPIOB,GPIO_Pin_15)
#define LED_1_EIN      GPIO_SetBits(GPIOB,GPIO_Pin_15)

#define LED_2_AUS      GPIO_ResetBits(GPIOB,GPIO_Pin_8)
#define LED_2_EIN      GPIO_SetBits(GPIOB,GPIO_Pin_8)

// Tasten
#define TASTE_1        GPIO_ReadInputDataBit(GPIOA,GPIO_Pin_0)



/* Private functions ---------------------------------------------------------*/


//***********************************************************************************************
// System-Einstellungen
//***********************************************************************************************
void SetupSystem (void) {

  GPIO_InitTypeDef  GPIO_InitStructure;

  RCC_DeInit ();                        // RCC System Reset(for debug purpose)

  // Enable HSE (Umschaltung auf externen Quarz)
  RCC_HSEConfig (RCC_HSE_ON);

  // HSE-Umschaltung abwarten
  while (RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET);

  // System-Taktung
  RCC_HCLKConfig   (RCC_SYSCLK_Div1);   // HCLK   = SYSCLK
  RCC_PCLK2Config  (RCC_HCLK_Div1);     // PCLK2 (APB2) = HCLK
  RCC_PCLK1Config  (RCC_HCLK_Div2);     // PCLK1 (APB1) = HCLK/2
  RCC_ADCCLKConfig (RCC_PCLK2_Div6);    // ADCCLK = PCLK2/6

  // FLASH-Speicher Zugriff
  FLASH_SetLatency(FLASH_Latency_2);                        // Flash - 2 wait states
  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);     // Pipeline freigeben

  // PLL Konfiguration
  // PLLCLK = 8MHz * 9 = 72 MHz
  RCC_PLLConfig (RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);     // Externer Quarz, Faktor 9
  RCC_PLLCmd (ENABLE);                                      // Enable PLL

  // PLL-Konfiguration abwarten
  while (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);

  // PLL als System-Takt auswhlen
  RCC_SYSCLKConfig (RCC_SYSCLKSource_PLLCLK);

  // PLL-Umschaltung abwarten
  while (RCC_GetSYSCLKSource() != 0x08);

  // GPIOs
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE); // GPIO A Takt freigeben
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE); // GPIO B Takt freigeben

  GPIO_InitStructure.GPIO_Pin   = GPIO_Pin_15;          // LED 1 Ausgang
  GPIO_InitStructure.GPIO_Mode  =  GPIO_Mode_Out_PP;    // Pin-Mode
  GPIO_InitStructure.GPIO_Speed =  GPIO_Speed_50MHz;    // Pin Taktung
  GPIO_Init(GPIOB, &GPIO_InitStructure);                // Port-Einstellung

  GPIO_InitStructure.GPIO_Pin   = GPIO_Pin_8;           // LED 2 Ausgang
  GPIO_InitStructure.GPIO_Mode  =  GPIO_Mode_Out_PP;    // Pin-Mode
  GPIO_InitStructure.GPIO_Speed =  GPIO_Speed_50MHz;    // Pin Taktung
  GPIO_Init(GPIOB, &GPIO_InitStructure);                // Port-Einstellung
 
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;             // Taste 1
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;         // Pin Mode
  GPIO_InitStructure.GPIO_Speed =  GPIO_Speed_50MHz;    // Pin Taktung
  GPIO_Init(GPIOA, &GPIO_InitStructure);                // Port-Einstellung


}

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{

    SetupSystem();


    while (1) {


        if(!TASTE_1) {
            LED_1_EIN;
            LED_2_AUS;
        } else {
            LED_2_EIN;
            LED_1_AUS;
        }
    } // end while

}

/**
  * @brief  Retargets the C library printf function to the USART.
  * @param  None
  * @retval None
  */

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */


/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
